Plotting
========

Plotting helpers provide quick visualization of canonical DataArrays. They are
thin wrappers around matplotlib and expect selection/filtering to be done
upstream.

.. toctree::
   :maxdepth: 2

   raster
   psth
   trajectory
